netapp_ontap.resources.cluster_ad_proxy API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.cluster_ad_proxy`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

This API configures data SVM account information at the Active Directory. For Active Directory domain-based authentication for cluster accounts, a data SVM must be configured and registered as a machine account at the Active Directory. All authentication requests are proxied through this SVM.

## Examples

### Creating a data SVM proxy for domain-based authentication for cluster accounts

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ClusterAdProxy

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = ClusterAdProxy()
        resource.svm.uuid = "13f87d78-70c7-11e9-b722-0050568ec89f"
        resource.post(hydrate=True)
        print(resource)

### Updating a data SVM proxy for domain-based authentication for cluster accounts

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ClusterAdProxy

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = ClusterAdProxy()
        resource.svm.uuid = "13f87d78-70c7-11e9-b722-0050568ec89f"
        resource.patch()

### Retrieving a data SVM proxy for domain-based authentication for cluster accounts

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import ClusterAdProxy

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = ClusterAdProxy()
        resource.get()
        print(resource)

Try it out

    ClusterAdProxy(
        {
            "_links": {"self": {"href": "/api/security/authentication/cluster/ad-proxy"}},
            "svm": {
                "name": "vs2",
                "uuid": "512eab7a-6bf9-11e9-a896-005056bb9ce1",
                "_links": {
                    "self": {"href": "/api/svm/svms/512eab7a-6bf9-11e9-a896-005056bb9ce1"}
                },
            },
        }
    )

## Classes

`class ClusterAdProxy (*args, **kwargs)`

  The SVM configured as proxy for Active Directory authentication of cluster accounts.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes the data SVM configured as a tunnel for Active Directory based authentication for cluster user accounts.

    ### Related ONTAP commands

    - `security login domain-tunnel delete`

    ### Learn more

    - `DOC /security/authentication/cluster/ad-proxy`
    - `DOC /security/accounts`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves SVM information configured as an Active Directory domain-tunnel.

    ### Related ONTAP commands

    - `security login domain-tunnel show`

    ### Learn more

    - `DOC /security/authentication/cluster/ad-proxy`
    - `DOC /security/accounts`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates the data SVM configured as a tunnel for Active Directory based authentication for cluster user accounts.

    ### Related ONTAP commands

    - `security login domain-tunnel modify`

    ### Learn more

    - `DOC /security/authentication/cluster/ad-proxy`
    - `DOC /security/accounts`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Configures a data SVM as a proxy for Active Directory based authentication for cluster user accounts.

    ### Required properties

    - `svm.name` or `svm.uuid` - Name and UUID of the SVM for a cluster user account.

    ### Related ONTAP commands

    - `security login domain-tunnel create`

    ### Learn more

    - `DOC /security/authentication/cluster/ad-proxy`
    - `DOC /security/accounts`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class ClusterAdProxySchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ClusterAdProxy object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `links GET`

    The links field of the cluster_ad_proxy.

  `svm GET POST PATCH`

    The svm field of the cluster_ad_proxy.